@@ -2,11 +2,12 @@
 
 import logging
 import time
+from typing import List
 
 from soco_cli.utils import convert_to_seconds, error_report, seconds_until
 
 
-def process_wait(sequence):
+def process_wait(sequence: List):
     if sequence[0] in ["wait", "wait_for"]:
         duration = 0
         if len(sequence) != 2:
